@@ -1,13 +1,14 @@
 # command line interface
 
 import sys
+
 import asyncclick as click
 
-from distkv.util import main_
 from distkv.exceptions import ClientError, ServerError
+from distkv.util import main_
 
 
-def cmd():
+def cmd(backend="trio"):
     """
     The main command entry point, as declared in ``setup.py``.
     """
@@ -19,7 +20,7 @@ def cmd():
         main_.help = """\
 This is DistKV, a distributed master-less key-value storage system.
 """
-        main_()
+        main_(_anyio_backend=backend)
     except (ClientError, ServerError) as err:
         print(type(err).__name__ + ":", *err.args, file=sys.stderr)
         sys.exit(1)
