@@ -7,6 +7,7 @@ import ruyaml as yaml
 
 from ._dict import attrdict
 from ._path import Path
+from ._msgpack import Proxy
 
 __all__ = ["yload", "yprint", "yformat", "yaml_named"]
 
@@ -16,6 +17,7 @@ Emitter = yaml.emitter.Emitter
 
 
 SafeRepresenter.add_representer(attrdict, SafeRepresenter.represent_dict)
+SafeConstructor.yaml_base_dict_type = attrdict
 
 
 def str_presenter(dumper, data):
@@ -28,6 +30,7 @@ def yaml_named(name: str, use_repr: bool = False):
     """
     A class decorator that allows representing an object in YAML
     """
+
     def register(cls):
         def str_me(dumper, data):
             return dumper.represent_scalar("!" + name, repr(data) if use_repr else str(data))
@@ -46,10 +49,16 @@ def _path_repr(dumper, data):
     # return ScalarNode(tag, value, style=style)
     # return yaml.events.ScalarEvent(anchor=None, tag='!P', implicit=(True, True), value=str(data))
 
+def _proxy_repr(dumper, data):
+    return dumper.represent_scalar("!R", data.name)
+    # return ScalarNode(tag, value, style=style)
+    # return yaml.events.ScalarEvent(anchor=None, tag='!P', implicit=(True, True), value=str(data))
+
 
 SafeRepresenter.add_representer(Path, _path_repr)
 SafeConstructor.add_constructor("!P", Path._make)
 
+SafeRepresenter.add_representer(Proxy, _proxy_repr)
 
 def _bin_from_ascii(loader, node):
     value = loader.construct_scalar(node)
@@ -90,11 +99,19 @@ def expect_node(self, *a, **kw):
 Emitter.expect_node = _expect_node
 
 
-def yload(stream, multi=False):
+def yload(stream, multi=False, attr=False):
     """
     Load one or more YAML objects from a file.
     """
     y = yaml.YAML(typ="safe")
+    if attr:
+
+        class AttrConstructor(SafeConstructor):
+            def __init__(self, *a, **k):
+                super().__init__(*a, **k)
+                self.yaml_base_dict_type = attrdict
+
+        y.Constructor = AttrConstructor
     if multi:
         return y.load_all(stream)
     else:
